/****************************************************************************
** Meta object code from reading C++ file 'cweekdaygraphicsview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/view/cweekdaygraphicsview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cweekdaygraphicsview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CWeekDayGraphicsview_t {
    QByteArrayData data[12];
    char stringdata0[143];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CWeekDayGraphicsview_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CWeekDayGraphicsview_t qt_meta_stringdata_CWeekDayGraphicsview = {
    {
QT_MOC_LITERAL(0, 0, 20), // "CWeekDayGraphicsview"
QT_MOC_LITERAL(1, 21, 19), // "signaleSwitchToView"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 9), // "focusDate"
QT_MOC_LITERAL(4, 52, 8), // "ViewType"
QT_MOC_LITERAL(5, 61, 4), // "type"
QT_MOC_LITERAL(6, 66, 12), // "setItemFocus"
QT_MOC_LITERAL(7, 79, 19), // "signalViewFocusInit"
QT_MOC_LITERAL(8, 99, 14), // "slotSwitchView"
QT_MOC_LITERAL(9, 114, 12), // "slotViewInit"
QT_MOC_LITERAL(10, 127, 13), // "slotPosOnView"
QT_MOC_LITERAL(11, 141, 1) // "y"

    },
    "CWeekDayGraphicsview\0signaleSwitchToView\0"
    "\0focusDate\0ViewType\0type\0setItemFocus\0"
    "signalViewFocusInit\0slotSwitchView\0"
    "slotViewInit\0slotPosOnView\0y"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CWeekDayGraphicsview[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   39,    2, 0x06 /* Public */,
       7,    0,   46,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    2,   47,    2, 0x0a /* Public */,
       9,    0,   52,    2, 0x0a /* Public */,
      10,    1,   53,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QDate, 0x80000000 | 4, QMetaType::Bool,    3,    5,    6,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QDate, QMetaType::Bool,    3,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,   11,

       0        // eod
};

void CWeekDayGraphicsview::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CWeekDayGraphicsview *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->signaleSwitchToView((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< ViewType(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 1: _t->signalViewFocusInit(); break;
        case 2: _t->slotSwitchView((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 3: _t->slotViewInit(); break;
        case 4: _t->slotPosOnView((*reinterpret_cast< const qreal(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CWeekDayGraphicsview::*)(const QDate & , ViewType , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CWeekDayGraphicsview::signaleSwitchToView)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CWeekDayGraphicsview::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CWeekDayGraphicsview::signalViewFocusInit)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CWeekDayGraphicsview::staticMetaObject = { {
    QMetaObject::SuperData::link<DragInfoGraphicsView::staticMetaObject>(),
    qt_meta_stringdata_CWeekDayGraphicsview.data,
    qt_meta_data_CWeekDayGraphicsview,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CWeekDayGraphicsview::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CWeekDayGraphicsview::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CWeekDayGraphicsview.stringdata0))
        return static_cast<void*>(this);
    return DragInfoGraphicsView::qt_metacast(_clname);
}

int CWeekDayGraphicsview::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DragInfoGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void CWeekDayGraphicsview::signaleSwitchToView(const QDate & _t1, ViewType _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CWeekDayGraphicsview::signalViewFocusInit()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
