/****************************************************************************
** Meta object code from reading C++ file 'lunarmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../src/dataManage/lunarmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lunarmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LunarManager_t {
    QByteArrayData data[8];
    char stringdata0[90];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LunarManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LunarManager_t qt_meta_stringdata_LunarManager = {
    {
QT_MOC_LITERAL(0, 0, 12), // "LunarManager"
QT_MOC_LITERAL(1, 13, 15), // "huangLiDayReady"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 4), // "date"
QT_MOC_LITERAL(4, 35, 16), // "CaHuangLiDayInfo"
QT_MOC_LITERAL(5, 52, 4), // "info"
QT_MOC_LITERAL(6, 57, 14), // "lunarInfoReady"
QT_MOC_LITERAL(7, 72, 17) // "festivalInfoReady"

    },
    "LunarManager\0huangLiDayReady\0\0date\0"
    "CaHuangLiDayInfo\0info\0lunarInfoReady\0"
    "festivalInfoReady"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LunarManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,
       6,    0,   34,    2, 0x06 /* Public */,
       7,    0,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QDate, 0x80000000 | 4,    3,    5,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void LunarManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<LunarManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->huangLiDayReady((*reinterpret_cast< const QDate(*)>(_a[1])),(*reinterpret_cast< const CaHuangLiDayInfo(*)>(_a[2]))); break;
        case 1: _t->lunarInfoReady(); break;
        case 2: _t->festivalInfoReady(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CaHuangLiDayInfo >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (LunarManager::*)(const QDate & , const CaHuangLiDayInfo & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LunarManager::huangLiDayReady)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (LunarManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LunarManager::lunarInfoReady)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (LunarManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&LunarManager::festivalInfoReady)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject LunarManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_LunarManager.data,
    qt_meta_data_LunarManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LunarManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LunarManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LunarManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LunarManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void LunarManager::huangLiDayReady(const QDate & _t1, const CaHuangLiDayInfo & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void LunarManager::lunarInfoReady()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LunarManager::festivalInfoReady()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
